@@ -95,5 +95,8 @@ MAX_SAMPLES = "max_samples"
 N_FEATURES = "n_features"
 """Number of features expected in the input data."""
 
+FEATURE_NAMES = "feature_names"
+"""Names of the features used for training."""
+
 SUPPORTED_STRING_TYPES = {"S", "U"}
 """Numpy string types suppoted by Humingbird."""
