@@ -26,11 +26,10 @@ def convert_onnx_scaler(operator, device=None, extra_config={}):
     Returns:
         A PyTorch model
     """
+    assert operator is not None, "Cannot convert None operator"
 
-    operator = operator.raw_operator
     offset = scale = None
-
-    for attr in operator.origin.attribute:
+    for attr in operator.raw_operator.origin.attribute:
         if attr.name == "offset":
             offset = np.array(attr.floats)
         if attr.name == "scale":
@@ -39,7 +38,7 @@ def convert_onnx_scaler(operator, device=None, extra_config={}):
     if any(v is None for v in [offset, scale]):
         raise RuntimeError("Error parsing Scalar, found unexpected None")
 
-    return Scaler(offset, scale, device)
+    return Scaler(operator, offset, scale, device)
 
 
 register_converter("ONNXMLScaler", convert_onnx_scaler)
